<template>
    <div class="page">
        <LayoutTable :data="tableData" :config="tableConfig">
            <el-button
                    slot="table-head-left2"
                    style="margin-left: 10px"
                    icon="el-icon-tickets"
                    size="mini"
                    @click="handleImport"
            >导入</el-button>
            <el-button
                    slot="table-head-left2"
                    style="margin-left: 10px"
                    icon="el-icon-tickets"
                    size="mini"
                    @click="doExport"
                    :disabled="isExport"
            >导出</el-button>
        </LayoutTable>
        <!-- ${functionName}导入对话框 -->
        <el-dialog
                :title="upload.title"
                :visible.sync="upload.open"
                width="400px"
                append-to-body
        >
            <el-upload
                    ref="upload"
                    :limit="1"
                    accept=".xlsx, .xls"
                    :headers="upload.headers"
                    :action="upload.url + '?updateSupport=' + upload.updateSupport"
                    :disabled="upload.isUploading"
                    :on-progress="handleFileUploadProgress"
                    :on-success="handleFileSuccess"
                    :auto-upload="false"
                    drag
            >
                <i class="el-icon-upload"></i>
                <div class="el-upload__text">
                    将文件拖到此处，或
                    <em>点击上传</em>
                </div>
                <div class="el-upload__tip" slot="tip">
                    <el-checkbox
                            v-model="upload.updateSupport"
                    />是否更新已经存在的数据
                    <el-link type="primary" style="font-size: 14px" @click="downloadTemplate"
                    >下载模板</el-link
                    >
                </div>
                <div class="el-upload__tip" style="color: red" slot="tip">
                    提示：仅允许导入“xls”或“xlsx”格式文件！
                </div>
            </el-upload>
            <div slot="footer" class="dialog-footer">
                <el-button type="primary" @click="submitFileForm">确 定</el-button>
                <el-button @click="upload.open = false">取 消</el-button>
            </div>
        </el-dialog>
    </div>
</template>

<script>
    import table from "@/assets/mixins/table";
    export default {
        components: {
        },
        mixins: [table],
        created() {
        },
        methods: {
            /** 导入 */
            handleImport() {
                this.upload.title = "${functionName}导入";
                this.upload.open = true;
            },
            /** 下载模板操作 */
            downloadTemplate() {
                this.isExport = true;
                this.$download("${RequestMapping}/downloadTemplate", {}, { type: "excel" })
                    .then(() => (this.isExport = false))
                    .catch((error) => {
                        this.isExport = false;
                        this.$message.error(error.message);
                    });
            },
            /** 文件上传中处理 */
            handleFileUploadProgress(event, file, fileList) {
                this.upload.isUploading = true;
            },
            /** 文件上传成功处理 */
            handleFileSuccess(response, file, fileList) {
                this.upload.open = false;
                this.upload.isUploading = false;
                this.$refs.upload.clearFiles();
                this.$alert(response.msg, "导入结果", { dangerouslyUseHTMLString: true });
                this.getData();
            },
            /** 提交上传文件 */
            submitFileForm() {
                this.$refs.upload.submit();
            },
            doExport() {
                this.isExport = true;
                this.$download("${RequestMapping}/exportExcel", {
                <#list columns as column>
                <#if column.isQuery == 1 >
                    'query.${column.javaField}': this.$route.query['query.${column.javaField}']<#sep>,
                </#if>
                </#list>
                }, {}).then(() => this.isExport = false).catch(error => {
                    this.isExport = false;
                    this.$message.error(error.message);
                });
            },
            <#if table.tplCategory=="sub">
            renderTable(tableData) {
                return (
                    <el-table stripe data={tableData} class="total-table">
                    {this.columnSet.map((item) => this.renderTableColumn(item))}
                    </el-table>
                );
            },
            renderTableColumn(options) {
                return (
                    <el-table-column
                        prop={options.prop}
                        label={options.label}
                    >
                    </el-table-column>
                 );
            },
            </#if>
        },
        data() {
            return {
                // 用户导入参数
                upload: {
                    // 是否显示弹出层（${functionName}导入）
                    open: false,
                    // 弹出层标题（${functionName}导入）
                    title: "导入${functionName}数据",
                    // 是否禁用上传
                    isUploading: false,
                    // 是否更新已经存在的数据
                    updateSupport: 0,
                    // 上传的地址
                    url: "/m/${RequestMapping}/importData",
                },
                isExport: false,
                <#if table.tplCategory=="sub">
                columnSet:[
                <#list subColumns as column>
                    {prop:"${column.javaField}",label:"${column.columnComment}"}<#sep>,
                </#list>
                ],
                </#if>
                config: {
                    search: [
                        <#list columns as column>
                        <#if column.isQuery == 1 &&column.htmlType==1>
                        {
                            name: "${column.javaField}",
                            type: "text",
                            label: "${column.columnComment}",
                            fuzzy: true
                        },
                        <#elseif column.isQuery == 1 &&column.htmlType==3>
                        {
                            name: "${column.javaField}",
                            type: "select",
                            label: "${column.columnComment}",
                            fuzzy: true
                        },
                        <#elseif column.isQuery == 1 &&column.htmlType==4>
                        {
                            name: "${column.javaField}",
                            type: "checkbox",
                            label: "${column.columnComment}",
                            fuzzy: true
                        },
                        <#elseif column.isQuery == 1 &&column.htmlType==6>
                        {
                            name: "${column.javaField}",
                            type: "date",
                            label: "${column.columnComment}",
                            fuzzy: true
                        },
                        </#if>
                        </#list>
                    ],
                    columns: [
                        {type: "selection", width: 60},
                        <#list columns as column>
                        <#if column.javaType == "Long">
                        {label: "${column.columnComment}", prop: "${column.javaField}", formatter: this.formatterString},
                        </#if>
                        <#if column.javaType == "String"||column.javaType == "Integer">
                        {label: "${column.columnComment}", prop: "${column.javaField}"},
                        </#if>
                        <#if column.javaType == "Date">
                        {label: "${column.columnComment}", prop: "${column.javaField}", formatter: this.formatterDate},
                        </#if>
                        <#if column.javaType == "BigDecimal">
                        {label: "${column.columnComment}", prop: "${column.javaField}", formatter: this.formatterMoney},
                        </#if>
                        </#list>
                        <#if table.tplCategory=="sub">
                        {label: "${subFunctionName}",
                          width: 120,
                          prop: "subColumns",
                          formatter: (row) => {
                              let widthsize=this.columnSet.length*150
                              return (
                                  <el-popover placement="right" width={widthsize} trigger="click">
                                      {this.renderTable(row.${subclassName}List)}
                                      <el-button type="text" slot="reference">详细</el-button>
                                  </el-popover>
                              );
                          },
                        },
                        </#if>
                        {
                            label: "操作",
                            width: 180,
                            formatter: row => {
                                return (
                                    <div><el-button type="primary" icon="el-icon-edit" round size='mini' onClick={()=>{this.toEdit(row)}}>编辑</el-button></div>
                            );
                            }
                        }
                    ]
                }
            };
        }
    };
</script>